audit

Function audit 

pub fn audit() -> Result<(IndicatedUpdateRequirement, NpmAuditData), Error>
main entry point for the npm-audit call

Errors

fails if the call to npm –version or to npm audit fails or if the result could not be parsed

Panics

panics if a new, unimplemented report format is encountered