pub struct Advisory {Show 21 fields
pub id: u64,
pub title: String,
pub findings: Vec<Finding>,
pub vulnerable_versions: Option<String>,
pub module_name: Option<String>,
pub severity: Severity,
pub github_advisory_id: Option<String>,
pub cves: Option<Vec<String>>,
pub access: String,
pub patched_versions: Option<String>,
pub recommendation: String,
pub cwe: Option<Vec<String>>,
pub found_by: Option<String>,
pub reported_by: Option<String>,
pub created: OffsetDateTime,
pub updated: Option<OffsetDateTime>,
pub deleted: Option<OffsetDateTime>,
pub references: Option<String>,
pub npm_advisory_id: Option<String>,
pub overview: String,
pub url: String,
}Expand description
advisory in report version 1
there is a field metadata in the output here but since I could not find information on its structure it is not parsed (was always null for me)
Fields
id: u64numeric id
title: Stringhuman readable title
findings: Vec<Finding>where was the module affected by this advisory found in the dependency tree
vulnerable_versions: Option<String>which versions of the affected module are vulnerable
module_name: Option<String>name of the affected node module
severity: Severityhow severe is the issue
github_advisory_id: Option<String>GitHub advisory Id
cves: Option<Vec<String>>CVE numbers
access: Stringif this advisory is public
patched_versions: Option<String>which versions of the affected package are patched
recommendation: Stringa human readable recommendation on how to fix this
cwe: Option<Vec<String>>a CWE (common weakness enumeration) identifier
found_by: Option<String>who found this security issue
reported_by: Option<String>who reported this security issue
created: OffsetDateTimewhen was this advisory created
updated: Option<OffsetDateTime>when was this advisory last updated
deleted: Option<OffsetDateTime>when was this deleted
references: Option<String>external references, all in one String, with newlines
npm_advisory_id: Option<String>npm advisory id
overview: Stringhuman-readable description
url: StringURL to learn more