pub fn outdated() -> Result<(IndicatedUpdateRequirement, NpmOutdatedData), Error>Expand description
main entry point for the npm-outdated call
Errors
fails if the call to npm outdated fails or if the output could not be parsed
pub fn outdated() -> Result<(IndicatedUpdateRequirement, NpmOutdatedData), Error>main entry point for the npm-outdated call
fails if the call to npm outdated fails or if the output could not be parsed